@@ -21,7 +21,7 @@ from .converters import (
     ElementData, XMLSchemaConverter, UnorderedConverter, ParkerConverter,
     BadgerFishConverter, AbderaConverter, JsonMLConverter
 )
-from .documents import validate, to_dict, to_json, from_json
+from .documents import validate, is_valid, iter_errors, to_dict, to_json, from_json
 
 from .validators import (
     XMLSchemaValidatorError, XMLSchemaParseError, XMLSchemaNotBuiltError,
@@ -31,7 +31,7 @@ from .validators import (
     XsdGlobals, XMLSchemaBase, XMLSchema, XMLSchema10, XMLSchema11
 )
 
-__version__ = '1.0.16'
+__version__ = '1.0.17'
 __author__ = "Davide Brunato"
 __contact__ = "brunato@sissa.it"
 __copyright__ = "Copyright 2016-2019, SISSA"
