@@ -306,7 +306,7 @@ class TestEncoding(XsdValidatorTestCase):
     def test_encode_unordered_content(self):
         schema = self.get_schema("""
         <xs:element name="A" type="A_type" />
-        <xs:complexType name="A_type">
+        <xs:complexType name="A_type" mixed="true">
             <xs:sequence>
                 <xs:element name="B1" type="xs:string"/>
                 <xs:element name="B2" type="xs:integer"/>
@@ -345,6 +345,39 @@ class TestEncoding(XsdValidatorTestCase):
             expected=XMLSchemaValidationError, indent=0, cdata_prefix='#'
         )
 
+    def test_encode_unordered_content_2(self):
+        """Here we test with a default converter at the schema level"""
+
+        schema = self.get_schema("""
+        <xs:element name="A" type="A_type" />
+        <xs:complexType name="A_type" mixed="true">
+            <xs:sequence>
+                <xs:element name="B1" type="xs:string"/>
+                <xs:element name="B2" type="xs:integer"/>
+                <xs:element name="B3" type="xs:boolean"/>
+            </xs:sequence>
+        </xs:complexType>
+        """, converter=UnorderedConverter)
+
+        self.check_encode(
+            xsd_component=schema.elements['A'],
+            data=ordered_dict_class([('B2', 10), ('B1', 'abc'), ('B3', True)]),
+            expected=u'<A>\n<B1>abc</B1>\n<B2>10</B2>\n<B3>true</B3>\n</A>',
+            indent=0, cdata_prefix='#'
+        )
+        self.check_encode(
+            xsd_component=schema.elements['A'],
+            data=ordered_dict_class([('B1', 'abc'), ('B2', 10), ('#1', 'hello'), ('B3', True)]),
+            expected=u'<A>\nhello<B1>abc</B1>\n<B2>10</B2>\n<B3>true</B3>\n</A>',
+            indent=0, cdata_prefix='#'
+        )
+        # FIXME: UnorderedConverter do not work, an XMLSchemaValidationError is expected!!
+        self.check_encode(
+            xsd_component=schema.elements['A'],
+            data=ordered_dict_class([('B1', 'abc'), ('B2', 10), ('#1', 'hello')]),
+            expected=u'<A>\nhello<B1>abc</B1>\n<B2>10</B2>\n</A>', indent=0, cdata_prefix='#'
+        )
+
     def test_strict_trailing_content(self):
         """Too many elements for a group raises an exception."""
         schema = self.get_schema("""
